openOBD Client by Jifeline Networks for Python 3

# Release notes:
- **1.23.x : 2025-07**
  - *Feature*: Support for DoIP communication
  - *Feature*: Reading the vehicle's voltage
- **1.22.x : 2025-07**
  - *Feature*: A list of ECUs detected in the vehicle can now be requested
- **1.20.x : 2025-06**
  - *Feature*: Added support for showing images in the user interface
- **1.19.x : 2025-06**
  - *Feature*: Added translations to the user interface
- **1.18.x : 2025-06**  
  - *Feature*: Support for function calls
  - *Feature*: Terminal 15 support
 - **1.17.x : 2024-12**  
    *Feature*: ISO14230 K-line support with Slow/Fast initialization  
    - Supported bitrates are 9600, 10k4 and 15k6
    - Supported protocol is KWP2000
 - **1.16.x : 2024-09**  
   First production release
 - **1.11.x** :  
   Beta release

---------------------------------------------------------------


